
#include <stdio.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include <ibxfcegui4/netk-util.h>

typedef struct Margins_obj
{
    GtkWidget *window;
    GtkWidget *entry_top;
    GtkWidget *entry_left;
    GtkWidget *entry_right;
    GtkWidget *entry_bottom;
}
Margins_obj;

void entry_set_margins(GtkWidget * button, gpointer data)
{
    DesktopMargins margins;
    Margins_obj *mo = (Margins_obj *) data;

    margins.top = atoi(gtk_entry_get_text(GTK_ENTRY(mo->entry_top)));
    margins.left = atoi(gtk_entry_get_text(GTK_ENTRY(mo->entry_left)));
    margins.right = atoi(gtk_entry_get_text(GTK_ENTRY(mo->entry_right)));
    margins.bottom = atoi(gtk_entry_get_text(GTK_ENTRY(mo->entry_bottom)));

    netk_set_desktop_margins(GDK_WINDOW_XWINDOW(mo->window->window), &margins);
}

void entry_get_margins(GtkWidget * button, gpointer data)
{
    DesktopMargins margins;
    Margins_obj *mo = (Margins_obj *) data;
    gchar *s;

    if(!netk_get_desktop_margins(DefaultScreenOfDisplay(GDK_DISPLAY()), &margins))
    {
        g_message("Cannot set desktop margins");
        return;
    }

    s = g_strdup_printf("%i", margins.top);
    gtk_entry_set_text(GTK_ENTRY(mo->entry_top), s);
    g_free(s);

    s = g_strdup_printf("%i", margins.left);
    gtk_entry_set_text(GTK_ENTRY(mo->entry_left), s);
    g_free(s);

    s = g_strdup_printf("%i", margins.right);
    gtk_entry_set_text(GTK_ENTRY(mo->entry_right), s);
    g_free(s);

    s = g_strdup_printf("%i", margins.bottom);
    gtk_entry_set_text(GTK_ENTRY(mo->entry_bottom), s);
    g_free(s);
}

int main(int argc, char *argv[])
{
    Margins_obj mo;
    GtkWidget *frame;
    GtkWidget *table;
    GtkWidget *label_top;
    GtkWidget *label_left;
    GtkWidget *label_right;
    GtkWidget *label_bottom;
    GtkWidget *set;
    GtkWidget *get;

    gtk_init(&argc, &argv);

    /* create a new window */
    mo.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);

    gtk_window_set_title(GTK_WINDOW(mo.window), "Margins");
    g_signal_connect(G_OBJECT(mo.window), "destroy", G_CALLBACK(gtk_main_quit), NULL);
    g_signal_connect_swapped(G_OBJECT(mo.window), "delete_event", G_CALLBACK(gtk_widget_destroy), mo.window);

    frame = gtk_frame_new(NULL);
    gtk_container_set_border_width(GTK_CONTAINER(frame), 0);
    gtk_container_add(GTK_CONTAINER(mo.window), frame);
    gtk_widget_show(frame);

    table = gtk_table_new(5, 2, TRUE);
    gtk_container_add(GTK_CONTAINER(frame), table);
    gtk_widget_show(table);

    label_top = gtk_label_new("Top :");
    gtk_table_attach_defaults(GTK_TABLE(table), label_top, 0, 1, 0, 1);
    gtk_widget_show(label_top);

    mo.entry_top = gtk_entry_new();
    gtk_entry_set_max_length(GTK_ENTRY(mo.entry_top), 4);
    gtk_entry_set_text(GTK_ENTRY(mo.entry_top), "");
    gtk_table_attach_defaults(GTK_TABLE(table), mo.entry_top, 1, 2, 0, 1);
    gtk_widget_show(mo.entry_top);

    label_right = gtk_label_new("Right :");
    gtk_table_attach_defaults(GTK_TABLE(table), label_right, 0, 1, 1, 2);
    gtk_widget_show(label_right);

    mo.entry_right = gtk_entry_new();
    gtk_entry_set_max_length(GTK_ENTRY(mo.entry_right), 4);
    gtk_entry_set_text(GTK_ENTRY(mo.entry_right), "");
    gtk_table_attach_defaults(GTK_TABLE(table), mo.entry_right, 1, 2, 1, 2);
    gtk_widget_show(mo.entry_right);

    label_left = gtk_label_new("Left :");
    gtk_table_attach_defaults(GTK_TABLE(table), label_left, 0, 1, 2, 3);
    gtk_widget_show(label_left);

    mo.entry_left = gtk_entry_new();
    gtk_entry_set_max_length(GTK_ENTRY(mo.entry_left), 4);
    gtk_entry_set_text(GTK_ENTRY(mo.entry_left), "");
    gtk_table_attach_defaults(GTK_TABLE(table), mo.entry_left, 1, 2, 2, 3);
    gtk_widget_show(mo.entry_left);

    label_bottom = gtk_label_new("Bottom :");
    gtk_table_attach_defaults(GTK_TABLE(table), label_bottom, 0, 1, 3, 4);
    gtk_widget_show(label_bottom);

    mo.entry_bottom = gtk_entry_new();
    gtk_entry_set_max_length(GTK_ENTRY(mo.entry_bottom), 4);
    gtk_entry_set_text(GTK_ENTRY(mo.entry_bottom), "");
    gtk_table_attach_defaults(GTK_TABLE(table), mo.entry_bottom, 1, 2, 3, 4);
    gtk_widget_show(mo.entry_bottom);

    set = gtk_button_new_with_label("Set");
    gtk_table_attach_defaults(GTK_TABLE(table), set, 0, 1, 4, 5);
    g_signal_connect(G_OBJECT(set), "clicked", G_CALLBACK(entry_set_margins), &mo);
    gtk_widget_show(set);

    get = gtk_button_new_with_label("Get");
    gtk_table_attach_defaults(GTK_TABLE(table), get, 1, 2, 4, 5);
    g_signal_connect(G_OBJECT(get), "clicked", G_CALLBACK(entry_get_margins), &mo);
    gtk_widget_show(get);

    gtk_widget_show(mo.window);

    gtk_main();

    return 0;
}
